# SMHI Swedish weather institute package
This package reads the weather information from SMHI open API and return as an object

Please visit http://opendata.smhi.se/apidocs/metfcst/parameters.html for information
